<xsl:stylesheet version = "1.0"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:a="http://alvis.info/enriched/"
                >

  <xsl:output method="text" />

  <xsl:param name="quiet"    >no</xsl:param>
  <xsl:param name="id"       >yes</xsl:param>
  <xsl:param name="tokens"   >no</xsl:param>
  <xsl:param name="words"    >no</xsl:param>
  <xsl:param name="sentences">no</xsl:param>
  <xsl:param name="nes"      >no</xsl:param>
  <xsl:param name="ne-type" />
  <xsl:param name="terms"    >no</xsl:param>


  <xsl:template match="a:documentCollection">
    <xsl:apply-templates select="a:documentRecord" />
  </xsl:template>

  <xsl:template match="a:documentRecord">
    <xsl:if test="$id = 'yes'">
      <xsl:if test="$quiet != 'yes'">
	<xsl:text>Document ID: </xsl:text>
      </xsl:if>
      <xsl:value-of select="@id" /><xsl:text>
</xsl:text>
    </xsl:if>
    <xsl:apply-templates select="a:linguisticAnalysis" />
  </xsl:template>

  <xsl:template match="a:linguisticAnalysis">
    <xsl:if test="$tokens = 'yes'">
      <xsl:call-template name="count-layer">
	<xsl:with-param name="nodes" select="./a:token_level/a:token" />
	<xsl:with-param name="layer">Tokens</xsl:with-param>
	<xsl:with-param name="quiet" select="$quiet" />
      </xsl:call-template>
    </xsl:if>
    <xsl:if test="$words = 'yes'">
      <xsl:call-template name="count-layer">
	<xsl:with-param name="nodes" select="./a:word_level/a:word" />
	<xsl:with-param name="layer">Words</xsl:with-param>
	<xsl:with-param name="quiet" select="$quiet" />
      </xsl:call-template>
    </xsl:if>
    <xsl:if test="$sentences = 'yes'">
      <xsl:call-template name="count-layer">
	<xsl:with-param name="nodes" select="./a:sentence_level/a:sentence" />
	<xsl:with-param name="layer">Sentences</xsl:with-param>
	<xsl:with-param name="quiet" select="$quiet" />
      </xsl:call-template>
    </xsl:if>
    <xsl:if test="$nes = 'yes'">
      <xsl:choose>
	<xsl:when test="$ne-type = ''">
	<xsl:call-template name="count-layer">
	  <xsl:with-param name="nodes" select="./a:semantic_unit_level/a:semantic_unit/a:named_entity" />
	  <xsl:with-param name="layer">Named entities</xsl:with-param>
	  <xsl:with-param name="quiet" select="$quiet" />
	</xsl:call-template>
	</xsl:when>
	<xsl:otherwise>
	  <xsl:call-template name="count-layer">
	    <xsl:with-param name="nodes" select="./a:semantic_unit_level/a:semantic_unit/a:named_entity[a:named_entity_type = $ne-type]" />
	    <xsl:with-param name="layer">Named entities (<xsl:value-of select="$ne-type" />)</xsl:with-param>
	    <xsl:with-param name="quiet" select="$quiet" />
	  </xsl:call-template>
	</xsl:otherwise>
      </xsl:choose>
      </xsl:if>
    <xsl:if test="$terms = 'yes'">
      <xsl:call-template name="count-layer">
	<xsl:with-param name="nodes" select="./a:semantic_unit_level/a:semantic_unit/a:term" />
	<xsl:with-param name="layer">Terms</xsl:with-param>
	<xsl:with-param name="quiet" select="$quiet" />
      </xsl:call-template>
    </xsl:if>
  </xsl:template>

  <xsl:template name="count-layer">
    <xsl:param name="nodes" />
    <xsl:param name="layer" />
    <xsl:param name="quiet">no</xsl:param>
    <xsl:if test="$quiet != 'yes'">
     <xsl:value-of select="$layer" /><xsl:text>: </xsl:text>
    </xsl:if>
    <xsl:value-of select="count($nodes)" /><xsl:text>
</xsl:text>
  </xsl:template>

</xsl:stylesheet>